[Libreoffice-commits] core.git: dbaccess/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Fri Oct 12 22:06:01 UTC 2018


 dbaccess/source/core/dataaccess/ModelImpl.cxx |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit e888ed185e9e4b254409959c7978e4d84f70d846
Author:     Eike Rathke <erack at redhat.com>
AuthorDate: Fri Oct 12 22:27:07 2018 +0200
Commit:     Eike Rathke <erack at redhat.com>
CommitDate: Sat Oct 13 00:05:35 2018 +0200

    Extract the one getUserLanguage() call from UserInformation
    
    After which we can ditch that.
    
    Change-Id: I6027327b41d98bffd47324b4c6145c1eddca632a
    Reviewed-on: https://gerrit.libreoffice.org/61733
    Reviewed-by: Eike Rathke <erack at redhat.com>
    Tested-by: Jenkins

diff --git a/dbaccess/source/core/dataaccess/ModelImpl.cxx b/dbaccess/source/core/dataaccess/ModelImpl.cxx
index abdd5242d27a..64bc6b16e8bd 100644
--- a/dbaccess/source/core/dataaccess/ModelImpl.cxx
+++ b/dbaccess/source/core/dataaccess/ModelImpl.cxx
@@ -55,6 +55,7 @@
 #include <vcl/errcode.hxx>
 #include <tools/urlobj.hxx>
 #include <unotools/sharedunocomponent.hxx>
+#include <unotools/configmgr.hxx>
 
 #include <algorithm>
 
@@ -690,9 +691,8 @@ const Reference< XNumberFormatsSupplier > & ODatabaseModelImpl::getNumberFormats
 {
     if (!m_xNumberFormatsSupplier.is())
     {
-        // the arguments : the locale of the current user
-        UserInformation aUserInfo;
-        Locale aLocale = aUserInfo.getUserLanguage();
+        // the arguments : the work locale of the current user
+        Locale aLocale( LanguageTag::convertToLocale( utl::ConfigManager::getWorkLocale(), false));
 
         m_xNumberFormatsSupplier.set( NumberFormatsSupplier::createWithLocale( m_aContext, aLocale ) );
     }


More information about the Libreoffice-commits mailing list